<?php
/**
 * WP Schema Injector
 *
 * @package       WPSCHEMAIN
 * @author        OZAIR WEBS
 * @license       gplv2
 * @version       1.3
 *
 * @wordpress-plugin
 * Plugin Name:   WP Schema Injector
 * Plugin URI:    https://ozairwebs.com/custom-schema-injector/
 * Description:   Custom Schema Injector is a dynamic WordPress plugin developed by Ozair Webs designed to simplify schema integration for posts, pages, custom post types, and taxonomies. With the increasing importance of structured data for search engine optimization (SEO) and enhancing search engine results, this plugin offers users a streamlined method for injecting custom schema (JSON-LD) code into individual pieces of content within their WordPress site. Below is a detailed overview of its features and functionality.
 * Version:       1.3
 * Author:        OZAIR WEBS
 * Author URI:    https://ozairwebs.com/about-us
 * Text Domain:   wp-schema-injector
 * Domain Path:   /languages
 * License:       GPLv2
 * License URI:   https://www.gnu.org/licenses/gpl-2.0.html
 *
 * You should have received a copy of the GNU General Public License
 * along with WP Schema Injector. If not, see <https://www.gnu.org/licenses/gpl-2.0.html/>.
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) exit;

/**
 * HELPER COMMENT START
 * 
 * This file contains the main information about the plugin.
 * It is used to register all components necessary to run the plugin.
 * 
 * The comment above contains all information about the plugin 
 * that are used by WordPress to differenciate the plugin and register it properly.
 * It also contains further PHPDocs parameter for a better documentation
 * 
 * The function WPSCHEMAIN() is the main function that you will be able to 
 * use throughout your plugin to extend the logic. Further information
 * about that is available within the sub classes.
 * 
 * HELPER COMMENT END
 */

// Plugin name
define( 'WPSCHEMAIN_NAME',			'WP Schema Injector' );

// Plugin version
define( 'WPSCHEMAIN_VERSION',		'1.3' );

// Plugin Root File
define( 'WPSCHEMAIN_PLUGIN_FILE',	__FILE__ );

// Plugin base
define( 'WPSCHEMAIN_PLUGIN_BASE',	plugin_basename( WPSCHEMAIN_PLUGIN_FILE ) );

// Plugin Folder Path
define( 'WPSCHEMAIN_PLUGIN_DIR',	plugin_dir_path( WPSCHEMAIN_PLUGIN_FILE ) );

// Plugin Folder URL
define( 'WPSCHEMAIN_PLUGIN_URL',	plugin_dir_url( WPSCHEMAIN_PLUGIN_FILE ) );

/**
 * Load the main class for the core functionality
 */
require_once WPSCHEMAIN_PLUGIN_DIR . 'core/class-wp-schema-injector.php';

/**
 * The main function to load the only instance
 * of our master class.
 *
 * @author  OZAIR WEBS
 * @since   1.3
 * @return  object|Wp_Schema_Injector
 */
function WPSCHEMAIN() {
	return Wp_Schema_Injector::instance();
}

WPSCHEMAIN();


// Function to initialize the plugin
function wpschemain_load_plugin() {
    // Include the core plugin class file
    require_once plugin_dir_path(__FILE__) . 'core/class-wp-schema-injector.php';

    // Initialize the plugin core class
    if (class_exists('Wp_Schema_Injector')) {
        Wp_Schema_Injector::instance();

        // Load additional classes for helpers, settings, and run logic
        require_once plugin_dir_path(__FILE__) . 'core/includes/classes/class-wp-schema-injector-helpers.php';
        require_once plugin_dir_path(__FILE__) . 'core/includes/classes/class-wp-schema-injector-settings.php';
        require_once plugin_dir_path(__FILE__) . 'core/includes/classes/class-wp-schema-injector-run.php';

        // Initialize the classes
        if (class_exists('Wp_Schema_Injector_Helpers') && class_exists('Wp_Schema_Injector_Settings')) {
            Wp_Schema_Injector::instance()->helpers = new Wp_Schema_Injector_Helpers();
            Wp_Schema_Injector::instance()->settings = new Wp_Schema_Injector_Settings();
        }

        // Log success for debugging
        error_log('WP Schema Injector loaded and initialized.');
    } else {
        error_log('Failed to load Wp_Schema_Injector class.');
    }
}

// Hook into plugins_loaded to initialize the plugin
add_action('plugins_loaded', 'wpschemain_load_plugin');

// Activation function for the plugin

function wpschemain_activate() {
    // Log successful activation (without unnecessary meta box checks)
    error_log('WP Schema Injector activated successfully.');
}

register_activation_hook(__FILE__, 'wpschemain_activate');

// Add meta box for custom schema
function wpschemain_add_meta_box() {
    add_meta_box(
        'wpschemain_custom_schema',       // ID
        'Custom Schema',                  // Title
        'wpschemain_display_meta_box',    // Callback
        'post',                           // Post type
        'normal',                         // Context
        'high'                            // Priority
    );
}
add_action('add_meta_boxes', 'wpschemain_add_meta_box');

// Display the meta box content
function wpschemain_display_meta_box($post) {
    $custom_schema = get_post_meta($post->ID, '_wpschemain_custom_schema', true);
    wp_nonce_field(basename(__FILE__), 'wpschemain_nonce');
    ?>
    <label for="wpschemain_custom_schema">Enter your custom schema (JSON-LD format):</label>
    <textarea name="wpschemain_custom_schema" id="wpschemain_custom_schema" rows="5" style="width:100%;"><?php echo esc_textarea($custom_schema); ?></textarea>
    <?php
}

// Save the custom schema when the post is saved
function wpschemain_save_custom_schema($post_id) {
    if (!isset($_POST['wpschemain_nonce']) || !wp_verify_nonce($_POST['wpschemain_nonce'], basename(__FILE__))) {
        return $post_id;
    }

    $custom_schema = isset($_POST['wpschemain_custom_schema']) ? $_POST['wpschemain_custom_schema'] : '';
    update_post_meta($post_id, '_wpschemain_custom_schema', $custom_schema);
}
add_action('save_post', 'wpschemain_save_custom_schema');
